@@ -90,6 +90,7 @@ class FileGDBTrivialIterator final : public FileGDBIterator
 
   public:
     explicit FileGDBTrivialIterator(FileGDBIterator *poParentIter);
+
     virtual ~FileGDBTrivialIterator()
     {
         delete poParentIter;
@@ -99,12 +100,15 @@ class FileGDBTrivialIterator final : public FileGDBIterator
     {
         return poTable;
     }
+
     virtual void Reset() override
     {
         iRow = 0;
         poParentIter->Reset();
     }
+
     virtual int GetNextRowSortedByFID() override;
+
     virtual int GetRowCount() override
     {
         return poTable->GetTotalRecordCount();
@@ -119,10 +123,12 @@ class FileGDBTrivialIterator final : public FileGDBIterator
     {
         return poParentIter->GetMinValue(eOutType);
     }
+
     virtual const OGRField *GetMaxValue(int &eOutType) override
     {
         return poParentIter->GetMaxValue(eOutType);
     }
+
     virtual int GetMinMaxSumCount(double &dfMin, double &dfMax, double &dfSum,
                                   int &nCount) override
     {
@@ -153,6 +159,7 @@ class FileGDBNotIterator final : public FileGDBIterator
     {
         return poTable;
     }
+
     virtual void Reset() override;
     virtual int GetNextRowSortedByFID() override;
     virtual int GetRowCount() override;
@@ -182,6 +189,7 @@ class FileGDBAndIterator final : public FileGDBIterator
     {
         return poIter1->GetTable();
     }
+
     virtual void Reset() override;
     virtual int GetNextRowSortedByFID() override;
 };
@@ -211,6 +219,7 @@ class FileGDBOrIterator final : public FileGDBIterator
     {
         return poIter1->GetTable();
     }
+
     virtual void Reset() override;
     virtual int GetNextRowSortedByFID() override;
     virtual int GetRowCount() override;
@@ -272,10 +281,12 @@ class FileGDBIndexIteratorBase : virtual public FileGDBIterator
 
   public:
     virtual ~FileGDBIndexIteratorBase();
+
     virtual FileGDBTable *GetTable() override
     {
         return poParent;
     }
+
     virtual void Reset() override;
 };
 
@@ -905,6 +916,8 @@ static const char *FileGDBSQLOpToStr(FileGDBSQLOp op)
             return ">=";
         case FGSO_GT:
             return ">";
+        case FGSO_ILIKE:
+            return "ILIKE";
     }
     return "unknown_op";
 }
@@ -999,12 +1012,41 @@ int FileGDBIndexIterator::SetConstraint(int nFieldIdx, FileGDBSQLOp op,
     returnErrorIf(eFieldType != FGFT_INT16 && eFieldType != FGFT_INT32 &&
                   eFieldType != FGFT_FLOAT32 && eFieldType != FGFT_FLOAT64 &&
                   eFieldType != FGFT_STRING && eFieldType != FGFT_DATETIME &&
-                  eFieldType != FGFT_GUID && eFieldType != FGFT_GLOBALID);
+                  eFieldType != FGFT_GUID && eFieldType != FGFT_GLOBALID &&
+                  eFieldType != FGFT_INT64 && eFieldType != FGFT_DATE &&
+                  eFieldType != FGFT_TIME &&
+                  eFieldType != FGFT_DATETIME_WITH_OFFSET);
 
-    const char *pszAtxName = CPLFormFilename(
-        CPLGetPath(poParent->GetFilename().c_str()),
-        CPLGetBasename(poParent->GetFilename().c_str()),
-        CPLSPrintf("%s.atx", poField->GetIndex()->GetIndexName().c_str()));
+    const auto poIndex = poField->GetIndex();
+
+    // Only supports ILIKE on a field string if the index expression starts
+    // with LOWER() and the string to compare with is only ASCII without
+    // wildcards
+    if (eOGRFieldType == OFTString &&
+        STARTS_WITH_CI(poIndex->GetExpression().c_str(), "LOWER("))
+    {
+        if (eOp == FGSO_ILIKE)
+        {
+            if (!CPLIsASCII(psValue->String, strlen(psValue->String)) ||
+                strchr(psValue->String, '%') || strchr(psValue->String, '_'))
+            {
+                return FALSE;
+            }
+        }
+        else if (eOp != FGSO_ISNOTNULL)
+        {
+            return FALSE;
+        }
+    }
+    else if (eOp == FGSO_ILIKE)
+    {
+        return FALSE;
+    }
+
+    const char *pszAtxName =
+        CPLFormFilename(CPLGetPath(poParent->GetFilename().c_str()),
+                        CPLGetBasename(poParent->GetFilename().c_str()),
+                        CPLSPrintf("%s.atx", poIndex->GetIndexName().c_str()));
 
     if (!ReadTrailer(pszAtxName))
         return FALSE;
@@ -1075,6 +1117,8 @@ int FileGDBIndexIterator::SetConstraint(int nFieldIdx, FileGDBSQLOp op,
         }
 
         case FGFT_DATETIME:
+        case FGFT_DATE:
+        case FGFT_DATETIME_WITH_OFFSET:
         {
             returnErrorIf(m_nValueSize != sizeof(double));
             if (eOp != FGSO_ISNOTNULL)
@@ -1085,7 +1129,11 @@ int FileGDBIndexIterator::SetConstraint(int nFieldIdx, FileGDBSQLOp op,
                 if (eOGRFieldType == OFTReal)
                     sValue.Real = psValue->Real;
                 else
-                    sValue.Real = FileGDBOGRDateToDoubleDate(psValue);
+                    sValue.Real = FileGDBOGRDateToDoubleDate(
+                        psValue, true,
+                        /* bHighPrecision= */ eFieldType ==
+                                FGFT_DATETIME_WITH_OFFSET ||
+                            poField->IsHighPrecision());
             }
             break;
         }
@@ -1107,6 +1155,30 @@ int FileGDBIndexIterator::SetConstraint(int nFieldIdx, FileGDBSQLOp op,
             break;
         }
 
+        case FGFT_INT64:
+            returnErrorIf(m_nValueSize != sizeof(int64_t));
+            if (eOp != FGSO_ISNOTNULL)
+            {
+                returnErrorIf(eOGRFieldType != OFTInteger64);
+                sValue.Integer64 = psValue->Integer64;
+            }
+            break;
+
+        case FGFT_TIME:
+        {
+            returnErrorIf(m_nValueSize != sizeof(double));
+            if (eOp != FGSO_ISNOTNULL)
+            {
+                returnErrorIf(eOGRFieldType != OFTReal &&
+                              eOGRFieldType != OFTTime);
+                if (eOGRFieldType == OFTReal)
+                    sValue.Real = psValue->Real;
+                else
+                    sValue.Real = FileGDBOGRTimeToDoubleTime(psValue);
+            }
+            break;
+        }
+
         default:
             CPLAssert(false);
             break;
@@ -1142,13 +1214,23 @@ int FileGDBIndexIterator::SetConstraint(int nFieldIdx, FileGDBSQLOp op,
 /************************************************************************/
 
 static int FileGDBUTF16StrCompare(const GUInt16 *pasFirst,
-                                  const GUInt16 *pasSecond, int nStrLen)
+                                  const GUInt16 *pasSecond, int nStrLen,
+                                  bool bCaseInsensitive)
 {
     for (int i = 0; i < nStrLen; i++)
     {
-        if (pasFirst[i] < pasSecond[i])
+        GUInt16 chA = pasFirst[i];
+        GUInt16 chB = pasSecond[i];
+        if (bCaseInsensitive)
+        {
+            if (chA >= 'a' && chA <= 'z')
+                chA -= 'a' - 'A';
+            if (chB >= 'a' && chB <= 'z')
+                chB -= 'a' - 'A';
+        }
+        if (chA < chB)
             return -1;
-        if (pasFirst[i] > pasSecond[i])
+        if (chA > chB)
             return 1;
     }
     return 0;
@@ -1227,6 +1309,18 @@ bool FileGDBIndexIterator::FindPages(int iLevel, int nPage)
                 break;
             }
 
+            case FGFT_INT64:
+            {
+                int64_t nVal =
+                    GetInt64(abyPage[iLevel] + nOffsetFirstValInPage, i);
+#ifdef DEBUG_INDEX_CONSISTENCY
+                returnErrorIf(i > 0 && nVal < nLastMax);
+                nLastMax = nVal;
+#endif
+                nComp = COMPARE(sValue.Integer64, nVal);
+                break;
+            }
+
             case FGFT_FLOAT32:
             {
                 float fVal =
@@ -1252,6 +1346,8 @@ bool FileGDBIndexIterator::FindPages(int iLevel, int nPage)
             }
 
             case FGFT_DATETIME:
+            case FGFT_DATE:
+            case FGFT_TIME:
             {
                 const double dfVal =
                     GetFloat64(abyPage[iLevel] + nOffsetFirstValInPage, i);
@@ -1279,12 +1375,17 @@ bool FileGDBIndexIterator::FindPages(int iLevel, int nPage)
                        nStrLen * sizeof(GUInt16));
                 for (int j = 0; j < nStrLen; j++)
                     CPL_LSBPTR16(&asMax[j]);
+                    // Note: we have an inconsistency. OGR SQL equality operator
+                    // is advertized top be case insensitive, but we have always
+                    // implemented FGSO_EQ as case sensitive.
 #ifdef DEBUG_INDEX_CONSISTENCY
-                returnErrorIf(i > 0 && FileGDBUTF16StrCompare(pasMax, asLastMax,
-                                                              nStrLen) < 0);
+                returnErrorIf(i > 0 &&
+                              FileGDBUTF16StrCompare(pasMax, asLastMax, nStrLen,
+                                                     eOp == FGSO_ILIKE) < 0);
                 memcpy(asLastMax, pasMax, nStrLen * 2);
 #endif
-                nComp = FileGDBUTF16StrCompare(asUTF16Str, pasMax, nStrLen);
+                nComp = FileGDBUTF16StrCompare(asUTF16Str, pasMax, nStrLen,
+                                               eOp == FGSO_ILIKE);
                 break;
             }
 
@@ -1334,6 +1435,7 @@ bool FileGDBIndexIterator::FindPages(int iLevel, int nPage)
                 break;
 
             case FGSO_EQ:
+            case FGSO_ILIKE:
                 if (iFirstPageIdx[iLevel] < 0)
                 {
                     if (nComp <= 0)
@@ -1373,7 +1475,7 @@ bool FileGDBIndexIterator::FindPages(int iLevel, int nPage)
                 }
                 break;
 
-            default:
+            case FGSO_ISNOTNULL:
                 CPLAssert(false);
                 break;
         }
@@ -1608,6 +1710,9 @@ int FileGDBIndexIterator::GetNextRow()
                 }
 
                 case FGFT_DATETIME:
+                case FGFT_DATE:
+                case FGFT_TIME:
+                case FGFT_DATETIME_WITH_OFFSET:
                 {
                     const double dfVal =
                         GetFloat64(abyPageFeature + nOffsetFirstValInPage,
@@ -1630,7 +1735,11 @@ int FileGDBIndexIterator::GetNextRow()
                            nStrLen * 2);
                     for (int j = 0; j < nStrLen; j++)
                         CPL_LSBPTR16(&asVal[j]);
-                    nComp = FileGDBUTF16StrCompare(asUTF16Str, asVal, nStrLen);
+                    // Note: we have an inconsistency. OGR SQL equality operator
+                    // is advertized top be case insensitive, but we have always
+                    // implemented FGSO_EQ as case sensitive.
+                    nComp = FileGDBUTF16StrCompare(asUTF16Str, asVal, nStrLen,
+                                                   eOp == FGSO_ILIKE);
                     break;
                 }
 
@@ -1644,6 +1753,15 @@ int FileGDBIndexIterator::GetNextRow()
                     break;
                 }
 
+                case FGFT_INT64:
+                {
+                    const int64_t nVal =
+                        GetInt64(abyPageFeature + nOffsetFirstValInPage,
+                                 iCurFeatureInPage);
+                    nComp = COMPARE(sValue.Integer64, nVal);
+                    break;
+                }
+
                 default:
                     CPLAssert(false);
                     nComp = 0;
@@ -1673,6 +1791,7 @@ int FileGDBIndexIterator::GetNextRow()
                     break;
 
                 case FGSO_EQ:
+                case FGSO_ILIKE:
                     if (nComp < 0 && bAscending)
                     {
                         bEOF = true;
@@ -1689,7 +1808,7 @@ int FileGDBIndexIterator::GetNextRow()
                     bMatch = nComp < 0;
                     break;
 
-                default:
+                case FGSO_ISNOTNULL:
                     CPLAssert(false);
                     break;
             }
@@ -1896,14 +2015,33 @@ const OGRField *FileGDBIndexIterator::GetMinMaxValue(OGRField *psField,
         }
 
         case FGFT_DATETIME:
+        case FGFT_DATETIME_WITH_OFFSET:
         {
             const double dfVal =
                 GetFloat64(l_abyPage + nOffsetFirstValInPage, iFeature);
-            FileGDBDoubleDateToOGRDate(dfVal, psField);
+            FileGDBDoubleDateToOGRDate(dfVal, false, psField);
             eOutType = OFTDateTime;
             return psField;
         }
 
+        case FGFT_DATE:
+        {
+            const double dfVal =
+                GetFloat64(l_abyPage + nOffsetFirstValInPage, iFeature);
+            FileGDBDoubleDateToOGRDate(dfVal, false, psField);
+            eOutType = OFTDate;
+            return psField;
+        }
+
+        case FGFT_TIME:
+        {
+            const double dfVal =
+                GetFloat64(l_abyPage + nOffsetFirstValInPage, iFeature);
+            FileGDBDoubleTimeToOGRTime(dfVal, psField);
+            eOutType = OFTTime;
+            return psField;
+        }
+
         case FGFT_STRING:
         {
             wchar_t awsVal[MAX_CAR_COUNT_INDEXED_STR + 1] = {0};
@@ -1940,6 +2078,15 @@ const OGRField *FileGDBIndexIterator::GetMinMaxValue(OGRField *psField,
             return psField;
         }
 
+        case FGFT_INT64:
+        {
+            const int64_t nVal =
+                GetInt64(l_abyPage + nOffsetFirstValInPage, iFeature);
+            psField->Integer64 = nVal;
+            eOutType = OFTInteger64;
+            return psField;
+        }
+
         default:
             CPLAssert(false);
             break;
@@ -1997,6 +2144,15 @@ struct Int32Getter
     }
 };
 
+struct Int64Getter
+{
+  public:
+    static double GetAsDouble(const GByte *pBaseAddr, int iOffset)
+    {
+        return static_cast<double>(GetInt64(pBaseAddr, iOffset));
+    }
+};
+
 struct Float32Getter
 {
   public:
@@ -2059,7 +2215,9 @@ int FileGDBIndexIterator::GetMinMaxSumCount(double &dfMin, double &dfMax,
     returnErrorIf(eOp != FGSO_ISNOTNULL);
     returnErrorIf(eFieldType != FGFT_INT16 && eFieldType != FGFT_INT32 &&
                   eFieldType != FGFT_FLOAT32 && eFieldType != FGFT_FLOAT64 &&
-                  eFieldType != FGFT_DATETIME);
+                  eFieldType != FGFT_DATETIME && eFieldType != FGFT_INT64 &&
+                  eFieldType != FGFT_DATE && eFieldType != FGFT_TIME &&
+                  eFieldType != FGFT_DATETIME_WITH_OFFSET);
 
     bool bSaveAscending = bAscending;
     bAscending = true;
@@ -2077,6 +2235,11 @@ int FileGDBIndexIterator::GetMinMaxSumCount(double &dfMin, double &dfMax,
             GetMinMaxSumCount<Int32Getter>(dfMin, dfMax, dfSum, nCount);
             break;
         }
+        case FGFT_INT64:
+        {
+            GetMinMaxSumCount<Int64Getter>(dfMin, dfMax, dfSum, nCount);
+            break;
+        }
         case FGFT_FLOAT32:
         {
             GetMinMaxSumCount<Float32Getter>(dfMin, dfMax, dfSum, nCount);
@@ -2084,6 +2247,9 @@ int FileGDBIndexIterator::GetMinMaxSumCount(double &dfMin, double &dfMax,
         }
         case FGFT_FLOAT64:
         case FGFT_DATETIME:
+        case FGFT_DATE:
+        case FGFT_TIME:
+        case FGFT_DATETIME_WITH_OFFSET:
         {
             GetMinMaxSumCount<Float64Getter>(dfMin, dfMax, dfSum, nCount);
             break;
@@ -2134,6 +2300,7 @@ class FileGDBSpatialIndexIteratorImpl final : public FileGDBIndexIteratorBase,
     {
         return poParent;
     }  // avoid MSVC C4250 inherits via dominance warning
+
     virtual int GetNextRowSortedByFID() override;
     virtual void Reset() override;
 
@@ -2325,18 +2492,6 @@ bool FileGDBSpatialIndexIteratorImpl::ReadNewXRange()
     return true;
 }
 
-/************************************************************************/
-/*                              GetInt64()                              */
-/************************************************************************/
-
-static GInt64 GetInt64(const GByte *pBaseAddr, int iOffset)
-{
-    GInt64 nVal;
-    memcpy(&nVal, pBaseAddr + sizeof(nVal) * iOffset, sizeof(nVal));
-    CPL_LSBPTR64(&nVal);
-    return nVal;
-}
-
 /************************************************************************/
 /*                         FindMinMaxIdx()                              */
 /************************************************************************/
