@@ -30,6 +30,7 @@
 #include <cstring>
 #include "ogr_pgdump.h"
 #include "cpl_conv.h"
+#include "cpl_md5.h"
 #include "cpl_string.h"
 
 /************************************************************************/
@@ -148,6 +149,15 @@ char *OGRPGCommonLaunderName(const char *pszSrcName, const char *pszDebugPrefix,
             }
         }
     }
+
+    if (i == OGR_PG_NAMEDATALEN - 1 && pszSafeName[i] != '\0')
+    {
+        constexpr int FIRST_8_CHARS_OF_MD5 = 8;
+        pszSafeName[i - FIRST_8_CHARS_OF_MD5 - 1] = '_';
+        memcpy(pszSafeName + i - FIRST_8_CHARS_OF_MD5, CPLMD5String(pszSrcName),
+               FIRST_8_CHARS_OF_MD5);
+    }
+
     pszSafeName[i] = '\0';
 
     if (strcmp(pszSrcName, pszSafeName) != 0)
@@ -274,7 +284,8 @@ OGRPGDumpDataSource::ICreateLayer(const char *pszLayerName,
             CPLFree(pszTmp);
         }
         else
-            osTable = pszDotPos + 1;  // skip "."
+            osTable = OGRPGCommonGenerateShortEnoughIdentifier(pszDotPos +
+                                                               1);  // skip "."
     }
     else
     {
@@ -286,7 +297,7 @@ OGRPGDumpDataSource::ICreateLayer(const char *pszLayerName,
             CPLFree(pszTmp);
         }
         else
-            osTable = pszLayerName;
+            osTable = OGRPGCommonGenerateShortEnoughIdentifier(pszLayerName);
     }
 
     const std::string osTableEscaped =
@@ -498,8 +509,8 @@ OGRPGDumpDataSource::ICreateLayer(const char *pszLayerName,
     if (bCreateTable && !osFIDColumnName.empty())
     {
         std::string osConstraintName(osTable);
-        if (bLaunder && osConstraintName.size() + strlen("_pk") >
-                            static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
+        if (osConstraintName.size() + strlen("_pk") >
+            static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
         {
             osConstraintName.resize(OGR_PG_NAMEDATALEN - 1 - strlen("_pk"));
         }
@@ -592,21 +603,8 @@ OGRPGDumpDataSource::ICreateLayer(const char *pszLayerName,
     std::vector<std::string> aosSpatialIndexCreationCommands;
     if (bCreateTable && bCreateSpatialIndex && pszGFldName && eType != wkbNone)
     {
-        std::string osIndexName(osTable);
-        std::string osSuffix("_");
-        osSuffix += pszGFldName;
-        osSuffix += "_geom_idx";
-        if (bLaunder)
-        {
-            if (osSuffix.size() >= static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
-            {
-                osSuffix = "_0_geom_idx";
-            }
-            if (osIndexName.size() + osSuffix.size() >
-                static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
-                osIndexName.resize(OGR_PG_NAMEDATALEN - 1 - osSuffix.size());
-        }
-        osIndexName += osSuffix;
+        const std::string osIndexName(OGRPGCommonGenerateSpatialIndexName(
+            osTable.c_str(), pszGFldName, 0));
 
         /* --------------------------------------------------------------- */
         /*      Create the spatial index.                                  */
